@@ -216,7 +216,7 @@ def np_to_pil(img):
     return PIL.Image.fromarray(img , 'L')
 
 def pil_to_np(img):
-    return numpy.reshape(numpy.asarray(img.getdata()), img.size)
+    return numpy.reshape(numpy.asarray(img.getdata(), dtype = numpy.uint8), img.size)
 
 def edit(img, *filters, scaling = 4, demo = False):
     '''def draw_grid(img, step, clear = False):
@@ -253,18 +253,28 @@ def edit(img, *filters, scaling = 4, demo = False):
         img = pil_to_np(img)
     return img
 
-def fits(img):
-    for x in range(img.size[0]):
-        if img.getpixel((x, 0)):
-            return False
-        if img.getpixel((x, img.size[1] - 1)):
-            return False
-    for y in range(img.size[1]):
-        if img.getpixel((0, y)):
-            return False
-        if img.getpixel((img.size[0] - 1, y)):
-            return False
-    return True
+def fits(img, threshold = 64):
+    is_np = img.__class__ == numpy.ndarray
+    is_pil = img.__class__ == PIL.Image.Image
+    if img.__class__ == numpy.ndarray:
+        #should change X and Y?
+        for x in range(img.shape[0]):
+            if img[x][0] > threshold or img[x][img.shape[1] - 1] > threshold:
+                return False
+        for y in range(img.shape[1]):
+            if img[0][y] > threshold or img[img.shape[0] - 1][y] > threshold:
+                return False
+        return True
+    elif img.__class__ == PIL.Image.Image:
+        for x in range(img.size[0]):
+            if img.getpixel((x, 0)) > threshold or img.getpixel((x, img.size[1] - 1)) > threshold:
+                return False
+        for y in range(img.size[1]):
+            if img.getpixel((0, y)) > threshold or img.getpixel((img.size[0] - 1, y)) > threshold:
+                return False
+        return True
+    else:
+        raise TypeError("img type is unknown, use 2-dim np array or pil grayscale image")
 
 def draw(*images, smooth = False, columns = 4):
     rows = math.ceil(len(images) / columns)
